==> Pyrogram-0.12.0-py3-none-any.whl: pyrogram/api/functions/help/save_app_log.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class SaveAppLog(Object):
    """Attributes:
        ID: ``0x6f02f748``

    Args:
        events: List of :obj:`InputAppEvent <pyrogram.api.types.InputAppEvent>`

    Raises:
        :obj:`RPCError <pyrogram.RPCError>`

    Returns:
        ``bool``
    """

    __slots__ = ["events"]

    ID = 0x6f02f748
    QUALNAME = "help.SaveAppLog"

    def __init__(self, *, events: list):
        self.events = events  # Vector<InputAppEvent>

    @staticmethod
    def read(b: BytesIO, *args) -> "SaveAppLog":
        # No flags
        
        events = Object.read(b)
        
        return SaveAppLog(events=events)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Vector(self.events))
        
        return b.getvalue()

==> Pyrogram-0.13.0-py3-none-any.whl: pyrogram/api/functions/help/save_app_log.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class SaveAppLog(Object):
    """Attributes:
        ID: ``0x6f02f748``

    Parameters:
        events: List of :obj:`InputAppEvent <pyrogram.api.types.InputAppEvent>`

    Returns:
        ``bool``
    """

    __slots__ = ["events"]

    ID = 0x6f02f748
    QUALNAME = "functions.help.SaveAppLog"

    def __init__(self, *, events: list):
        self.events = events  # Vector<InputAppEvent>

    @staticmethod
    def read(b: BytesIO, *args) -> "SaveAppLog":
        # No flags
        
        events = Object.read(b)
        
        return SaveAppLog(events=events)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Vector(self.events))
        
        return b.getvalue()
